==> hinemos_src-3.0.5.tar.gz: Hinemos_src-3.0.5/ClusterControl/src/com/clustercontrol/action/FacilityTree.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.action;

import java.rmi.RemoteException;
import java.util.Locale;

import javax.ejb.FinderException;
import javax.naming.NamingException;

import com.clustercontrol.bean.FacilityTreeItem;
import com.clustercontrol.repository.ejb.session.RepositoryController;
import com.clustercontrol.util.EjbConnectionManager;

/**
 * スコープツリーアイテムを取得するクライアント側アクションクラス<BR>
 * 
 * @version 1.0.0
 * @since 1.0.0
 */
public class FacilityTree {

    /**
     * スコープツリー構造を返します。
     * 
     * @return スコープツリー構造
     */
    public FacilityTreeItem getTreeItem(boolean scopeOnly) {
        RepositoryController repository = EjbConnectionManager
                .getConnectionManager().getRepositoryController();
        FacilityTreeItem item = null;
        try {
            if (scopeOnly) {
                item = repository.getScopeFacilityTree(Locale.getDefault());
            } else {
                item = repository.getFacilityTree(Locale.getDefault());
            }
        } catch (RemoteException e) {
        } catch (FinderException e) {
        } catch (NamingException e) {
        }
        return item;
    }

    /**
     * セパレータを取得します。<BR>
     * 
     * スコープの区切り文字（セパレータ）を取得します。
     * 
     * @return セパレータ文字列
     */
    public String getSeparator() {
        RepositoryController repository = EjbConnectionManager
                .getConnectionManager().getRepositoryController();
        String separator = ">";
        try {
            separator = repository.getSeparator();
        } catch (RemoteException e) {
        }
        return separator;
    }
}

==> hinemos_src-3.1.4.tar.gz: Hinemos_src-3.1.4/ClusterControl/src/com/clustercontrol/action/FacilityTree.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.action;

import java.rmi.RemoteException;
import java.util.HashMap;
import java.util.Locale;

import javax.ejb.FinderException;
import javax.naming.NamingException;

import com.clustercontrol.bean.FacilityTreeItem;
import com.clustercontrol.repository.ejb.session.RepositoryController;
import com.clustercontrol.util.EjbConnectionManager;

/**
 * スコープツリーアイテムを取得するクライアント側アクションクラス<BR>
 * 
 * @version 1.0.0
 * @since 1.0.0
 */
public class FacilityTree {
	// ファシリティツリーのクライアント側ローカルキャッシュを保持
	private static final HashMap<Boolean, FacilityTreeItem> m_fcilityTreeCache = new HashMap<Boolean, FacilityTreeItem>();

    /**
     * スコープツリー構造を返します。
     * 
     * @return スコープツリー構造
     */
    public FacilityTreeItem getTreeItem(boolean scopeOnly) {
        RepositoryController repository = EjbConnectionManager
                .getConnectionManager().getRepositoryController();
        
        FacilityTreeItem item = null;
        // キャッシュから取得する
        synchronized (m_fcilityTreeCache) {
            item = m_fcilityTreeCache.get(scopeOnly);
		}
        
        if(item != null){
        	return item;
        }
        try {
            if (scopeOnly) {
                item = repository.getScopeFacilityTree(Locale.getDefault());
            } else {
                item = repository.getFacilityTree(Locale.getDefault());
            }
            
            // キャッシュに保存する
            synchronized (m_fcilityTreeCache) {
            	m_fcilityTreeCache.put(scopeOnly, item);
            }
        } catch (RemoteException e) {
        } catch (FinderException e) {
        } catch (NamingException e) {
        }
        return item;
    }

    /**
     * セパレータを取得します。<BR>
     * 
     * スコープの区切り文字（セパレータ）を取得します。
     * 
     * @return セパレータ文字列
     */
    public String getSeparator() {
        RepositoryController repository = EjbConnectionManager
                .getConnectionManager().getRepositoryController();
        String separator = ">";
        try {
            separator = repository.getSeparator();
        } catch (RemoteException e) {
        }
        return separator;
    }
    
    /**
     * 保持しているローカルキャッシュをクリアする
     */
    public static void clearCache(){
        // キャッシュ情報を削除する
        synchronized (m_fcilityTreeCache) {
        	m_fcilityTreeCache.clear();
        }
    }
}
